# © 2024 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import _, api, fields, models
from odoo.exceptions import UserError


class FinancialProductTemplate(models.AbstractModel):
    _name = "financial.product.template"
    _description = "Template produit financier"
    _check_company_auto = True

    name = fields.Char(required=True)
    category_id = fields.Many2one(
        comodel_name="financial.product.category",
        string="Nom de la gamme",
        required=True,
        check_company=True,
        ondelete="restrict",
    )
    active = fields.Boolean(
        default=True,
        tracking=1,
    )
    description = fields.Text()
    company_id = fields.Many2one(
        comodel_name="res.company",
        string="Société",
        change_default=True,
        required=True,
        readonly=True,
        default=lambda self: self.env.company,
    )
    currency_id = fields.Many2one(
        comodel_name="res.currency", related="company_id.currency_id"
    )
    date_start = fields.Date("Début de validité")
    date_end = fields.Date("Fin de validité")

    # ------------------------------------------------------
    # Constrains functions
    # ------------------------------------------------------
    @api.constrains("date_start", "date_end")
    def _check_date_validity(self):
        for product in self:
            if (
                product.date_start
                and product.date_end
                and product.date_end <= product.date_start
            ):
                raise UserError(
                    _("La date de fin doit être supérieure à la date de début")
                )

    # ------------------------------------------------------
    # Computed fields / Search Fields
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Actions
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Override ORM
    # ------------------------------------------------------

    # ------------------------------------------------------
    # CRUD (Override ORM)
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Business functions
    # ------------------------------------------------------
